@@ -10,11 +10,11 @@ Apache2::Authen::OdinAuth - A cookie-based single sign-on module for Apache.
 
 =head1 VERSION
 
-Version 0.5
+Version 0.8
 
 =cut
 
-our $VERSION = 0.6;
+our $VERSION = 0.8;
 
 use Crypt::OdinAuth;
 
@@ -97,11 +97,21 @@ happen in mod_perl.
 
 use constant RELOAD_TIMEOUT => 10*60; # reload config every 10 minutes
 
+=head1 SUBROUTINES
+
+=head2 Configuration closure
+
+=cut
 {
   my $last_reload_time = -1;
   my $config_file = undef;
   my $config = undef;
 
+=head3 config
+
+Reloads configuration if older than RELOAD_TIMEOUT
+
+=cut
   sub config {
     if ( time() - $last_reload_time > RELOAD_TIMEOUT ) {
       $config = YAML::XS::LoadFile($config_file);
@@ -109,6 +119,11 @@ use constant RELOAD_TIMEOUT => 10*60; # reload config every 10 minutes
     $config;
   }
 
+=head3 init_config(request)
+
+Finds config file and loads it for the first time
+
+=cut
   sub init_config {
     my $r = shift;
     $config_file ||=
@@ -119,7 +134,11 @@ use constant RELOAD_TIMEOUT => 10*60; # reload config every 10 minutes
 
 $| = 1;
 
+=head2 handler(request)
 
+Main Apache mod_perl handler
+
+=cut
 sub handler {
   #
   # get URL
@@ -295,7 +314,11 @@ sub handler {
   return &redir($r, config->{not_on_list_url});
 }
 
+=head2 redir(request, target, reason)
 
+Redirect to Authorizer App
+
+=cut
 sub redir {
   my ($r, $target, $reason) = @_;
   my $ref = &urlencode($r->construct_url($r->unparsed_uri));
@@ -306,7 +329,11 @@ sub redir {
   return Apache2::Const::REDIRECT;
 }
 
+=head2 parse_cookie_jar(jar)
 
+Parse cookies into a hashref
+
+=cut
 sub parse_cookie_jar {
   my ($jar) = @_;
 
@@ -323,13 +350,18 @@ sub parse_cookie_jar {
   return $out;
 }
 
+=head2 urldecode(str)
 
+=cut
 sub urldecode {
   $_[0] =~ s!\+! !g;
   $_[0] =~ s/%([a-fA-F0-9]{2,2})/chr(hex($1))/eg;
   return $_[0];
 }
 
+=head2 urlencode(str)
+
+=cut
 sub urlencode {
   $_[0] =~ s!([^a-zA-Z0-9-_ ])! sprintf('%%%02x', ord $1) !gex;
   $_[0] =~ s! !+!g;
